import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import SUILoader from './SUILoader';
var TYPES = {
  FULL: 'full',
  SECTION: 'section'
};
var DELAY = 500; // ms

var BASE_CLASS = 'sui-AtomSpinner';
var CLASS_FULL = BASE_CLASS + "--fullPage";
var CLASS_NO_BACKGROUND = BASE_CLASS + "--noBackground";

var getParentClassName = function getParentClassName(_ref) {
  var _cx;

  var type = _ref.type,
      noBackground = _ref.noBackground;
  return cx((_cx = {}, _cx[BASE_CLASS] = type === TYPES.SECTION, _cx[CLASS_FULL] = type === TYPES.FULL, _cx[CLASS_NO_BACKGROUND] = noBackground, _cx));
};

var addParentClass = function addParentClass(parentNodeClassList) {
  return function (parentClassName) {
    return parentNodeClassList.add.apply(parentNodeClassList, parentClassName.split(' '));
  };
};

var removeParentClass = function removeParentClass(parentNodeClassList) {
  return function (parentClassName) {
    return parentNodeClassList.remove.apply(parentNodeClassList, parentClassName.split(' '));
  };
};

var AtomSpinner = function AtomSpinner(_ref2) {
  var delayedFromProps = _ref2.delayed,
      loader = _ref2.loader,
      type = _ref2.type,
      noBackground = _ref2.noBackground;

  var _useState = useState(delayedFromProps),
      delayed = _useState[0],
      setDelayed = _useState[1];

  var refSpinner = useRef();
  useEffect(function () {
    var parentClassName = getParentClassName({
      type: type,
      noBackground: noBackground
    });
    var parentNodeClassList = refSpinner.current.parentNode.classList;
    if (!delayed) addParentClass(parentNodeClassList)(parentClassName);
    var timer = setTimeout(function () {
      setDelayed(false);
      addParentClass(parentNodeClassList)(parentClassName);
    }, DELAY);
    return function () {
      clearTimeout(timer);
      removeParentClass(parentNodeClassList)(parentClassName);
    };
  }, [delayed, noBackground, type]);
  return React.createElement("span", {
    ref: refSpinner
  }, !delayed ? loader : React.createElement("noscript", null));
};

AtomSpinner.displayName = 'AtomSpinner';
AtomSpinner.defaultProps = {
  delayed: false,
  type: TYPES.SECTION,
  loader: React.createElement(SUILoader, null)
};
export default AtomSpinner;
export { TYPES as AtomSpinnerTypes };